@@ -46,6 +46,39 @@ from lxml.cssselect import CSSSelector
 
 from .util import TrackSubClasses, import_module_from_source
 
+from .html2txt import html2text
+from .ical2txt import ical2text
+
+try:
+    from bs4 import BeautifulSoup
+except ImportError:
+    BeautifulSoup = None
+
+try:
+    import jsbeautifier
+except ImportError:
+    jsbeautifier = None
+
+try:
+    import cssbeautifier
+except ImportError:
+    cssbeautifier = None
+
+try:
+    import pdftotext
+except ImportError:
+    pdftotext = None
+
+try:
+    import pytesseract
+except ImportError:
+    pytesseract = None
+
+try:
+    from PIL import Image
+except ImportError:
+    Image = None
+
 logger = logging.getLogger(__name__)
 
 
@@ -82,7 +115,8 @@ class FilterBase(object, metaclass=TrackSubClasses):
             filter_instance = filtercls(state.job, state)
             if filter_instance.match():
                 logger.info('Auto-applying filter %r to %s', filter_instance, state.job.get_location())
-                data = filter_instance.filter(data)
+                # filters require a subfilter argument
+                data = filter_instance.filter(data, None)
 
         return data
 
@@ -217,6 +251,9 @@ class LegacyHooksPyFilter(FilterBase):
         return self.hooks is not None
 
     def filter(self, data, subfilter):
+        if subfilter is not None:
+            logger.warning('Legacy hooks filter does not have any subfilter -- ignored')
+
         try:
             result = self.hooks.filter(self.job.get_location(), data)
             if result is None:
@@ -235,14 +272,10 @@ class BeautifyFilter(FilterBase):
     __no_subfilter__ = True
 
     def filter(self, data, subfilter):
-        from bs4 import BeautifulSoup as bs
-        soup = bs(data, features="lxml")
+        if BeautifulSoup is None:
+            raise ImportError('Please install BeautifulSoup')
 
-        try:
-            import jsbeautifier
-        except ImportError:
-            logger.info('"jsbeautifier" is not installed, will not beautify <script> tags')
-            jsbeautifier = None
+        soup = BeautifulSoup(data, features="lxml")
 
         if jsbeautifier is not None:
             scripts = soup.find_all('script')
@@ -250,12 +283,8 @@ class BeautifyFilter(FilterBase):
                 if script.string is not None:
                     beautified_js = jsbeautifier.beautify(script.string)
                     script.string = beautified_js
-
-        try:
-            import cssbeautifier
-        except ImportError:
-            logger.info('"cssbeautifier" is not installed, will not beautify <style> tags')
-            cssbeautifier = None
+        else:
+            logger.info('"jsbeautifier" is not installed, will not beautify <script> tags')
 
         if cssbeautifier is not None:
             styles = soup.find_all('style')
@@ -263,6 +292,8 @@ class BeautifyFilter(FilterBase):
                 if style.string is not None:
                     beautified_css = cssbeautifier.beautify(style.string)
                     style.string = beautified_css
+        else:
+            logger.info('"cssbeautifier" is not installed, will not beautify <style> tags')
 
         return soup.prettify()
 
@@ -288,7 +319,6 @@ class Html2TextFilter(FilterBase):
             method = 're'
             options = {}
 
-        from .html2txt import html2text
         return html2text(data, baseurl=getattr(self.job, 'url', getattr(self.job, 'navigate', '')),
                          method=method, options=options)
 
@@ -312,7 +342,9 @@ class Pdf2TextFilter(FilterBase):
         if not isinstance(data, bytes):
             raise ValueError('The pdf2text filter needs bytes input (is it the first filter?)')
 
-        import pdftotext
+        if pdftotext is None:
+            raise ImportError('Please install pdftotext')
+
         return '\n\n'.join(pdftotext.PDF(io.BytesIO(data), password=subfilter.get('password', '')))
 
 
@@ -324,7 +356,6 @@ class Ical2TextFilter(FilterBase):
     __no_subfilter__ = True
 
     def filter(self, data, subfilter):
-        from .ical2txt import ical2text
         return ical2text(data)
 
 
@@ -782,7 +813,7 @@ class ShellPipeFilter(FilterBase):
 
     __default_subfilter__ = 'command'
 
-    def filter(self, data, subfilter=None):
+    def filter(self, data, subfilter):
         if 'command' not in subfilter:
             raise ValueError('{} filter needs a command'.format(self.__kind__))
 
@@ -817,6 +848,10 @@ class OCRFilter(FilterBase):
         language = subfilter.get('language', None)
         timeout = int(subfilter.get('timeout', 10))
 
-        import pytesseract
-        from PIL import Image
+        if pytesseract is None:
+            raise ImportError('Please install pytesseract')
+
+        if Image is None:
+            raise ImportError('Please install Pillow/PIL')
+
         return pytesseract.image_to_string(Image.open(io.BytesIO(data)), lang=language, timeout=timeout)
