@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of urlwatch (https://thp.io/2008/urlwatch/).
-# Copyright (c) 2008-2019 Thomas Perl <m@thp.io>
+# Copyright (c) 2008-2020 Thomas Perl <m@thp.io>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -28,15 +28,23 @@
 # THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
-def ical2text(ical_string):
+try:
     import vobject
+except ImportError:
+    vobject = None
+
+
+def ical2text(ical_string):
+    if vobject is None:
+        raise ImportError('Please install vobject')
+
     result = []
     if isinstance(ical_string, str):
         parsedCal = vobject.readOne(ical_string)
     else:
         try:
             parsedCal = vobject.readOne(ical_string)
-        except Exception as e:
+        except Exception:
             parsedCal = vobject.readOne(ical_string.decode('utf-8', 'ignore'))
 
     for event in parsedCal.getChildren():
